==> windmill-api-1.5.0.tar.gz: windmill-api-1.5.0/windmill_api/api/user/create_token.py <==
from typing import Any, Dict

import httpx

from ...client import Client
from ...models.create_token_json_body import CreateTokenJsonBody
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: CreateTokenJsonBody,
) -> Dict[str, Any]:
    url = "{}/users/tokens/create".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    *,
    client: Client,
    json_body: CreateTokenJsonBody,
) -> Response[Any]:
    """create token

    Args:
        json_body (CreateTokenJsonBody):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    *,
    client: Client,
    json_body: CreateTokenJsonBody,
) -> Response[Any]:
    """create token

    Args:
        json_body (CreateTokenJsonBody):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)

==> windmill-api-1.10.0.tar.gz: windmill-api-1.10.0/windmill_api/api/user/create_token.py <==
from typing import Any, Dict

import httpx

from ...client import Client
from ...models.create_token_json_body import CreateTokenJsonBody
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: CreateTokenJsonBody,
) -> Dict[str, Any]:
    url = "{}/users/tokens/create".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _build_response(*, response: httpx.Response) -> Response[None]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    *,
    client: Client,
    json_body: CreateTokenJsonBody,
) -> Response[None]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    *,
    client: Client,
    json_body: CreateTokenJsonBody,
) -> Response[None]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)
